@@ -379,6 +379,12 @@ class TestNetworkElementUpdate(unittest.TestCase):
         ne.admin_disabled = None
         self.assertEqual(ne.admin_disabled, None)
 
+        self.assertEqual(ne.extra, None)
+        ne.extra = '{"key": "value"}'
+        self.assertEqual(ne.extra, '{"key": "value"}')
+        ne.extra = None
+        self.assertEqual(ne.extra, None)
+
         # Interface
         intf = ne.interfaces.add()
         intf.id = '1'
@@ -1058,6 +1064,17 @@ class TestNetworkElementUpdate(unittest.TestCase):
         self.assertEqual(len(radio.errctx.errors), 2)
         radio.errctx = None
 
+        self.assertEqual(radio.admin_up, None)
+        radio.admin_up = True
+        self.assertEqual(radio.admin_up, True)
+        radio.admin_up = None
+        self.assertEqual(radio.admin_up, None)
+
+        self.assertEqual(radio.oper_up, None)
+        radio.oper_up = True
+        self.assertEqual(radio.oper_up, True)
+        radio.oper_up = None
+        self.assertEqual(radio.oper_up, None)
 
         # RadioStream
         stream = radio.streams.add()
@@ -1258,13 +1275,11 @@ class TestNetworkElementUpdate(unittest.TestCase):
         wlink.poller_hash = poller_hash
         self.assertEqual(poller_hash, wlink.poller_hash)
 
-
         # RfAggregationGroup
         rf_aggr_gr = intf.rf_aggregation_groups.add()
         rf_aggr_gr.name = 'RadioGr1'
         self.assertEqual(rf_aggr_gr.name, 'RadioGr1')
 
-
         rf_aggr_gr.errctx = network_element_update.ErrorContext()
         self.assertEqual(rf_aggr_gr.airtime, None)
         rf_aggr_gr.airtime = 19.2
@@ -1614,4 +1629,3 @@ class TestNetworkElementUpdate(unittest.TestCase):
         self.assertEqual(len(link.bridged_mac_addresses), 2)
         self.assertEqual(link.bridged_mac_addresses[0], '00:01:02:03:04:05')
         self.assertEqual(link.bridged_mac_addresses[1], '00:01:02:03:04:06')
-
